==> deepin-image-viewer_5.7.4.orig.tar.xz: deepin-image-viewer-5.7.4/src/translations/deepin-image-viewer_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Visor de imágenes</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Visor de imágenes de Deepin es una herramienta de visualización de imágenes elegante y agradable.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imágenes</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Información de imagen</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt + Enter</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt + Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Este archivo contiene varias páginas. Use Evince para ver todas las páginas.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Abrir carpeta</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No tiene permisos para ver esta imagen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No se encontró el archivo de imagen</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Fecha de modificación</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño de archivo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fecha de la captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Longitud focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espacio de color</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Sin escala</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Ajustar página a la imagen</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Ajustar imagen a la página</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escalar a:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetros </translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetros</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Pulgadas</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posición de la imagen</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escalado</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Ajustes de la imagen</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Ajustes de imagen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persianas</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Conmutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Corredizo</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Anillo</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Ingrese un nuevo nombre</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Seleccionar carpeta</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Esta carpeta está desactivada para sincronización</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Administración de carpetas sincronizadas</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>La lista de carpetas esta vacía</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancelar sincronización</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>El dispositivo fue removido</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Esta carpeta ya no existe</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculando…</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualización de imágenes</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Finalizar presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Quitar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información sobre la imagen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla siguiente</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuevo álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Salir de pantalla completa</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Reducir</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Por favor ingrese un nuevo atajo</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Ver imágen</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restaurar a los valores predeterminados</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Finalizar presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Quitar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información de imágen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuevo álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Ajustes de presentación</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Cambiar efecto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Cambiar duración</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segundos</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Mi favorito</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamaño 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar a la ventana</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Administrar imágen</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Tamaño</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Encaja en la ventana</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No se econtraron archivos de imágen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No se encontró el archivo de imagen</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Ajustes de presentación</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efecto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nuevo álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Cronología</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Añadir a álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Añadir a nuevo álbum</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Salir de pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Quitar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar ventana de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar ventana de navegación</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información de imagen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas las imágenes</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Dibujar</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>No se encontró el archivo de imagen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualización de imágenes</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Salir de pantalla completa</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información de imágen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Reducir</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Visor de imágenes</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Visor de imágenes de Deepin es una herramienta de visualización de imágenes elegante y agradable.</translation>
    </message>
</context>
</TS>
